@@ -62,8 +62,8 @@ class CategoryForm(FlaskForm):
     # Only validate top level category choice
     # Subcategory choices are dynamic
     cat1 = SelectField('Category', [InputRequired()])
-    cat2 = SelectField(validate_choice=False)
-    cat3 = SelectField(validate_choice=False)
+    cat2 = SelectField(choices=[], validate_choice=False)
+    cat3 = SelectField(choices=[], validate_choice=False)
 
     submit = SubmitField('Next')
 
@@ -71,7 +71,7 @@ class CategoryForm(FlaskForm):
 class PostForm(FlaskForm):
     """Ad post form"""
 
-    adtype = SelectField('Ad Type', choices=[], validate_choice=False)
+    adtype = SelectField('Ad Type')
     adtitle = StringField('Ad Title', [InputRequired(), Length(min=8, max=64, message='Title must be between %(min)d and %(max)d characters')])
     description = TextAreaField('Description', [InputRequired(), Length(min=10, message='Description must be %(min)d or more characters')])
 
@@ -84,12 +84,11 @@ class PostForm(FlaskForm):
     pricetype = SelectField('Price Type', choices=pricetype_choices)
     price = DecimalField('Price', [RequiredIfFieldEqualTo('pricetype', pricetype_choices[0][0]), NumberRange(min=1), Optional()])
 
-    loc1 = SelectField('Location', validate_choice=False)
-    loc2 = SelectField(validate_choice=False)
-    loc3 = SelectField(validate_choice=False)
+    loc1 = SelectField('Location')
+    loc2 = SelectField(choices=[], validate_choice=False)
+    loc3 = SelectField(choices=[], validate_choice=False)
     postalcode = StringField('Postal Code', [InputRequired(), PostalCode()])
-    # TODO: Implement full address field
-    #fulladdress = StringField('Full Address')
+    fulladdress = StringField('Full Address')
     phone = StringField('Phone', [PhoneNumber(), Optional()])
 
     images = ['jpg', 'jpeg', 'png', 'gif', 'bmp']  # Kijiji supported image formats
