@@ -1,15 +1,12 @@
 from xml.parsers.expat import ExpatError, errors
 
 import httpx
+import pgeocode
 import xmltodict
 
 
 class KijijiApiException(Exception):
-    def __init__(self, msg):
-        self.msg = msg
-
-    def __str__(self):
-        return f"KijijiApiException: {self.msg}"
+    """KijijiApi class exception"""
 
 
 class KijijiApi:
@@ -381,7 +378,18 @@ class KijijiApi:
             return doc
         else:
             raise KijijiApiException(self._error_reason(doc))
-
+    
+    def geo_location(self, postal_code):
+        # pgeocode.Nominatim.query_postal_code only uses the first three characters to do the lookup for Canadian postal codes
+        postalcode = postal_code[:3]
+        try:
+            nomi = pgeocode.Nominatim('ca')
+            location = nomi.query_postal_code(postalcode)
+        except Exception as e:
+            raise KijijiApiException(f'Error acquiring geo location data: {e}')
+        else:
+            return location
+    
     @staticmethod
     def _headers_with_auth(user_id, token):
         return {'X-ECG-Authorization-User': f'id="{user_id}", token="{token}"'}
