@@ -39,9 +39,20 @@ def post_manual():
     form = PostManualForm()
     if form.validate_on_submit():
         if form.file.data:
-            ad_id = kijiji_api.post_ad(current_user.id, current_user.token, form.file.data.read())
+            xml_payload = form.file.data.read()
+
+            ad_id = kijiji_api.post_ad(current_user.id, current_user.token, xml_payload)
             flash(f'Manually posted ad {ad_id}')
 
+            # Save ad payload
+            user_dir = os.path.join(current_app.instance_path, 'user', current_user.id)
+            if not os.path.exists(user_dir):
+                os.makedirs(user_dir)
+            ad_file = os.path.join(user_dir, f'{ad_id}.xml')
+            with open(ad_file, 'w', encoding='utf-8') as f:
+                f.write(xml_payload)
+            flash(f'Ad {ad_id} payload saved to {ad_file}')
+
     if form.errors:
         flash(form.errors)
     return render_template('post_manual.html', form=form)
@@ -101,6 +112,7 @@ def post():
         default_ad_desc = current_app.config.get('DEFAULT_AD_DESCRIPTION')
         default_ad_price = current_app.config.get('DEFAULT_AD_PRICE')
         default_postalcode = current_app.config.get('DEFAULT_POSTAL_CODE')
+        default_fulladdress = current_app.config.get('DEFAULT_FULL_ADDRESS')
         default_phone = current_app.config.get('DEFAULT_PHONE')
         try:
             # Only apply default values if one was given
@@ -112,6 +124,8 @@ def post():
                 form.price.data = float(default_ad_price)
             if default_postalcode:
                 form.postalcode.data = str(default_postalcode)
+            if default_fulladdress:
+                form.fulladdress.data = str(default_fulladdress)
             if default_phone:
                 form.phone.data = str(default_phone)
         except (TypeError, ValueError) as e:
@@ -218,6 +232,9 @@ def post():
         # Default to 'Canada' => '0' if none given
         location_choice = (lambda x1, x2, x3: x3 if x3 else x2 if x2 else x1 if x1 else '0')(form.loc1.data, form.loc2.data, form.loc3.data)
 
+        # Generate Geo Location Data
+        location = kijiji_api.geo_location(form.postalcode.data)
+
         # Begin assembling entire payload
         # All of the keys in the following dict are always present in every ad post payload,
         # however some may be left empty if not used
@@ -246,11 +263,12 @@ def post():
                 'ad:phone': form.phone.data,
                 'ad:ad-address': {
                     'types:radius': 400,
-                    'types:latitude': None,
-                    'types:longitude': None,
-                    'types:full-address': None,
+                    'types:latitude': location.latitude,
+                    'types:longitude': location.longitude,
+                    'types:full-address': form.fulladdress.data,
                     'types:zip-code': form.postalcode.data,
                 },
+                'ad:visible-on-map': 'true',  # appears to make no difference if set to 'true' or 'false'
                 'attr:attributes': create_attribute_payload(attrib_form.data),
                 'pic:pictures': create_picture_payload(form.data),
                 'vid:videos': None,
